#!/usr/bin/env bash

# Exit immediately on any failure
set -e
set -o pipefail

if ! [ -x "$(command -v docker)" ]; then
    echo 'Error: docker is not installed.' >&2
    exit 1
fi

if ! [ -x "$(command -v git)" ]; then
    echo 'Error: git is not installed.' >&2
    exit 1
fi

if ! [ -x "$(command -v awk)" ]; then
    echo 'Error: awk is not installed.' >&2
    exit 1
fi

if ! [ -n "$1" ]; then
    echo "Error: missing 1st argument of $0, i.e. namespace of the container image." >&2
    exit 1
fi

if ! [ -n "$2" ]; then
    echo "Error: missing 2nd argument of $0, i.e. version of the container image." >&2
    exit 1
fi

IMAGE_NAMESPACE="$1"
IMAGE_VERSION="$2"

docker build \
    --build-arg=IMAGE_CREATED="$(date --utc --rfc-3339=seconds)" \
    --build-arg=IMAGE_VERSION="${IMAGE_VERSION}" \
    --build-arg=IMAGE_REVISION="$(git show --pretty=oneline | tac | tail -n 1 | awk '{print $1}')" \
    --tag="${IMAGE_NAMESPACE}/sonar-scanner-cli:${IMAGE_VERSION}" \
    .

exit 0
